@@ -1294,6 +1294,8 @@ static errr Infofnt_init_data(cptr name)
 	info = XLoadQueryFont(Metadpy->dpy, name);
 
 	/* The load failed, try to recover */
+	if (!info) info = XLoadQueryFont(Metadpy->dpy, "6x13");
+
 	if (!info) return (-1);
 
 
@@ -2527,7 +2529,7 @@ static errr term_data_init(term_data *td, int i)
 	/* Prepare the standard font */
 	MAKE(td->fnt, infofnt);
 	Infofnt_set(td->fnt);
-	if (Infofnt_init_data(font)) quit_fmt("Couldn't load the requested font. (%s)", font);
+	if (Infofnt_init_data(font)) quit_fmt("Couldn't load the requested font (%s) -- you may have to restart Xorg to make FontPath active.", font);
 
 	/* Hack -- key buffer size */
 	num = ((i == 0) ? 1024 : 16);
